@@ -26,17 +26,24 @@
 
 #include <explain/syscall.h>
 #include <explain/syscall/accept.h>
+#include <explain/syscall/accept4.h>
 #include <explain/syscall/access.h>
+#include <explain/syscall/acct.h>
+#include <explain/syscall/adjtime.h>
+#include <explain/syscall/adjtimex.h>
 #include <explain/syscall/bind.h>
 #include <explain/syscall/chdir.h>
 #include <explain/syscall/chmod.h>
 #include <explain/syscall/chown.h>
+#include <explain/syscall/chroot.h>
 #include <explain/syscall/close.h>
 #include <explain/syscall/closedir.h>
 #include <explain/syscall/connect.h>
 #include <explain/syscall/creat.h>
+#include <explain/syscall/dirfd.h>
 #include <explain/syscall/dup.h>
 #include <explain/syscall/dup2.h>
+#include <explain/syscall/eventfd.h>
 #include <explain/syscall/execve.h>
 #include <explain/syscall/execvp.h>
 #include <explain/syscall/fchdir.h>
@@ -45,26 +52,35 @@
 #include <explain/syscall/fcntl.h>
 #include <explain/syscall/fdopen.h>
 #include <explain/syscall/ferror.h>
+#include <explain/syscall/fflush.h>
 #include <explain/syscall/fgetc.h>
 #include <explain/syscall/fgets.h>
+#include <explain/syscall/fileno.h>
+#include <explain/syscall/flock.h>
 #include <explain/syscall/fopen.h>
 #include <explain/syscall/fork.h>
 #include <explain/syscall/fpathconf.h>
 #include <explain/syscall/fputc.h>
 #include <explain/syscall/fread.h>
 #include <explain/syscall/fstat.h>
+#include <explain/syscall/fstatfs.h>
+#include <explain/syscall/ftime.h>
 #include <explain/syscall/ftruncate.h>
 #include <explain/syscall/futimes.h>
 #include <explain/syscall/fwrite.h>
 #include <explain/syscall/getc.h>
 #include <explain/syscall/getchar.h>
 #include <explain/syscall/getcwd.h>
+#include <explain/syscall/getdomainname.h>
+#include <explain/syscall/getgroups.h>
+#include <explain/syscall/gethostname.h>
 #include <explain/syscall/getpeername.h>
 #include <explain/syscall/getrlimit.h>
 #include <explain/syscall/getsockname.h>
 #include <explain/syscall/getsockopt.h>
 #include <explain/syscall/gettimeofday.h>
 #include <explain/syscall/ioctl.h>
+#include <explain/syscall/kill.h>
 #include <explain/syscall/lchown.h>
 #include <explain/syscall/link.h>
 #include <explain/syscall/listen.h>
@@ -72,36 +88,65 @@
 #include <explain/syscall/lstat.h>
 #include <explain/syscall/malloc.h>
 #include <explain/syscall/mkdir.h>
+#include <explain/syscall/nice.h>
 #include <explain/syscall/opendir.h>
 #include <explain/syscall/open.h>
 #include <explain/syscall/pathconf.h>
 #include <explain/syscall/pclose.h>
 #include <explain/syscall/pipe.h>
 #include <explain/syscall/popen.h>
+#include <explain/syscall/pread.h>
 #include <explain/syscall/putc.h>
 #include <explain/syscall/putchar.h>
+#include <explain/syscall/pwrite.h>
 #include <explain/syscall/read.h>
 #include <explain/syscall/readdir.h>
 #include <explain/syscall/readlink.h>
+#include <explain/syscall/readv.h>
 #include <explain/syscall/realloc.h>
 #include <explain/syscall/remove.h>
 #include <explain/syscall/rename.h>
 #include <explain/syscall/rmdir.h>
 #include <explain/syscall/select.h>
+#include <explain/syscall/setdomainname.h>
+#include <explain/syscall/setgroups.h>
+#include <explain/syscall/sethostname.h>
 #include <explain/syscall/setsockopt.h>
+#include <explain/syscall/signalfd.h>
 #include <explain/syscall/socket.h>
 #include <explain/syscall/stat.h>
+#include <explain/syscall/statfs.h>
+#include <explain/syscall/strdup.h>
 #include <explain/syscall/strerror.h>
+#include <explain/syscall/strndup.h>
+#include <explain/syscall/strtod.h>
+#include <explain/syscall/strtof.h>
+#include <explain/syscall/strtol.h>
+#include <explain/syscall/strtold.h>
+#include <explain/syscall/strtoll.h>
+#include <explain/syscall/strtoul.h>
+#include <explain/syscall/strtoull.h>
 #include <explain/syscall/symlink.h>
 #include <explain/syscall/system.h>
+#include <explain/syscall/tcdrain.h>
+#include <explain/syscall/tcflow.h>
+#include <explain/syscall/tcflush.h>
+#include <explain/syscall/tcgetattr.h>
+#include <explain/syscall/tcsendbreak.h>
+#include <explain/syscall/tcsetattr.h>
+#include <explain/syscall/telldir.h>
+#include <explain/syscall/time.h>
+#include <explain/syscall/timerfd_create.h>
 #include <explain/syscall/truncate.h>
 #include <explain/syscall/unlink.h>
+#include <explain/syscall/ustat.h>
 #include <explain/syscall/utime.h>
 #include <explain/syscall/wait.h>
 #include <explain/syscall/wait3.h>
 #include <explain/syscall/wait4.h>
 #include <explain/syscall/waitpid.h>
 #include <explain/syscall/write.h>
+#include <explain/syscall/writev.h>
 
 
 typedef struct table_t table_t;
@@ -116,12 +161,12 @@ static const table_t table[] =
 {
     /* ----------  A  ------------------------------------------------------- */
     { "accept", explain_syscall_accept },
+    { "accept4", explain_syscall_accept4 },
     { "access", explain_syscall_access },
-    /* FIXME: add support for acct */
-    /* FIXME: add support for add_key */
-    /* FIXME: add support for adjtimex */
+    { "acct", explain_syscall_acct },
+    { "adjtime", explain_syscall_adjtime },
+    { "adjtimex", explain_syscall_adjtimex },
     /* FIXME: add support for afs_syscall */
-    /* FIXME: add support for alarm */
     /* FIXME: add support for alloc_hugepages */
     /* ----------  B  ------------------------------------------------------- */
     /* FIXME: add support for bdflush */
@@ -135,7 +180,7 @@ static const table_t table[] =
     { "chdir", explain_syscall_chdir },
     { "chmod", explain_syscall_chmod },
     { "chown", explain_syscall_chown },
-    /* FIXME: add support for chroot */
+    { "chroot", explain_syscall_chroot },
     /* FIXME: add support for clock_getres */
     /* FIXME: add support for clock_gettime */
     /* FIXME: add support for clock_nanosleep */
@@ -148,7 +193,7 @@ static const table_t table[] =
     /* FIXME: add support for create_module */
     /* ----------  D  ------------------------------------------------------- */
     /* FIXME: add support for delete_module */
-    /* FIXME: add support for dirfd */
+    { "dirfd", explain_syscall_dirfd },
     { "dup", explain_syscall_dup },
     { "dup2", explain_syscall_dup2 },
     /* ----------  E  ------------------------------------------------------- */
@@ -156,7 +201,7 @@ static const table_t table[] =
     /* FIXME: add support for epoll_ctl */
     /* FIXME: add support for epoll_pwait */
     /* FIXME: add support for epoll_wait */
-    /* FIXME: add support for eventfd */
+    { "eventfd", explain_syscall_eventfd },
     { "execve", explain_syscall_execve },
     { "execvp", explain_syscall_execvp },
     /* ----------  F  ------------------------------------------------------- */
@@ -171,14 +216,14 @@ static const table_t table[] =
     { "fdopen", explain_syscall_fdopen },
     /* FIXME: add support for fdopendir */
     { "ferror", explain_syscall_ferror },
-    /* FIXME: add support for fflush */
+    { "fflush", explain_syscall_fflush },
     { "fgetc", explain_syscall_fgetc },
     /* FIXME: add support for fgetpos */
     { "fgets", explain_syscall_fgets },
     /* FIXME: add support for fgetxattr */
-    /* FIXME: add support for fileno */
+    { "fileno", explain_syscall_fileno },
     /* FIXME: add support for flistxattr */
-    /* FIXME: add support for flock */
+    { "flock", explain_syscall_flock },
     { "fopen", explain_syscall_fopen },
     { "fork", explain_syscall_fork },
     { "fpathconf", explain_syscall_fpathconf },
@@ -194,10 +239,10 @@ static const table_t table[] =
     /* FIXME: add support for fsetpos */
     /* FIXME: add support for fsetxattr */
     { "fstat", explain_syscall_fstat },
-    /* FIXME: add support for fstatfs */
+    { "fstatfs", explain_syscall_fstatfs },
     /* FIXME: add support for fsync */
     /* FIXME: add support for ftell */
-    /* FIXME: add support for ftime */
+    { "ftime", explain_syscall_ftime },
     { "ftruncate", explain_syscall_ftruncate },
     /* FIXME: add support for futex */
     { "futimes", explain_syscall_futimes },
@@ -208,10 +253,9 @@ static const table_t table[] =
     /* FIXME: add support for getcpu */
     { "getcwd", explain_syscall_getcwd },
     /* FIXME: add support for getdents */
-    /* FIXME: add support for getegid */
-    /* FIXME: add support for geteuid */
-    /* FIXME: add support for getgid */
-    /* FIXME: add support for getgroups */
+    { "getdomainname", explain_syscall_getdomainname },
+    { "getgroups", explain_syscall_getgroups },
+    { "gethostname", explain_syscall_gethostname },
     /* FIXME: add support for getitimer */
     /* FIXME: add support for get_kernel_syms */
     /* FIXME: add support for get_mempolicy */
@@ -235,7 +279,6 @@ static const table_t table[] =
     /* FIXME: add support for get_thread_area */
     /* FIXME: add support for gettid */
     { "gettimeofday", explain_syscall_gettimeofday },
-    /* FIXME: add support for getuid */
     /* FIXME: add support for getw */
     /* FIXME: add support for getxattr */
     /* FIXME: add support for gtty */
@@ -261,7 +304,7 @@ static const table_t table[] =
     /* ----------  K  ------------------------------------------------------- */
     /* FIXME: add support for kexec_load */
     /* FIXME: add support for keyctl */
-    /* FIXME: add support for kill */
+    { "kill", explain_syscall_kill },
     /* ----------  L  ------------------------------------------------------- */
     { "lchown", explain_syscall_lchown },
     /* FIXME: add support for lgetxattr */
@@ -312,7 +355,7 @@ static const table_t table[] =
     /* ----------  N  ------------------------------------------------------- */
     /* FIXME: add support for nanosleep */
     /* FIXME: add support for nfsservctl */
-    /* FIXME: add support for nice */
+    { "nice", explain_syscall_nice },
     /* ----------  O  ------------------------------------------------------- */
     { "open", explain_syscall_open },
     { "opendir", explain_syscall_opendir },
@@ -332,7 +375,7 @@ static const table_t table[] =
     { "popen", explain_syscall_popen },
     /* FIXME: add support for ppoll */
     /* FIXME: add support for prctl */
-    /* FIXME: add support for pread */
+    { "pread", explain_syscall_pread },
     /* FIXME: add support for printf */
     /* FIXME: add support for prof */
     /* FIXME: add support for profil */
@@ -343,7 +386,7 @@ static const table_t table[] =
     /* FIXME: add support for putpmsg */
     /* FIXME: add support for puts */
     /* FIXME: add support for putw */
-    /* FIXME: add support for pwrite */
+    { "pwrite", explain_syscall_pwrite },
     /* ----------  Q  ------------------------------------------------------- */
     /* FIXME: add support for query_module */
     /* FIXME: add support for quotactl */
@@ -352,7 +395,7 @@ static const table_t table[] =
     /* FIXME: add support for readahead */
     { "readdir", explain_syscall_readdir },
     { "readlink", explain_syscall_readlink },
-    /* FIXME: add support for readv */
+    { "readv", explain_syscall_readv },
     { "realloc", explain_syscall_realloc },
     /* FIXME: add support for reboot */
     /* FIXME: add support for recv */
@@ -365,7 +408,6 @@ static const table_t table[] =
     /* FIXME: add support for request_key */
     /* FIXME: add support for restart_syscall */
     /* FIXME: add support for rewind */
-    /* FIXME: add support for rewinddir */
     { "rmdir", explain_syscall_rmdir },
     /* FIXME: add support for rt_sigaction */
     /* FIXME: add support for rt_sigpending */
@@ -388,7 +430,6 @@ static const table_t table[] =
     /* FIXME: add support for sched_setscheduler */
     /* FIXME: add support for sched_yield */
     /* FIXME: add support for security */
-    /* FIXME: add support for seekdir */
     { "select", explain_syscall_select },
     /* FIXME: add support for semctl */
     /* FIXME: add support for semget */
@@ -400,12 +441,12 @@ static const table_t table[] =
     /* FIXME: add support for sendto */
     /* FIXME: add support for setbuf */
     /* FIXME: add support for setbuffer */
-    /* FIXME: add support for setdomainname */
+    { "setdomainname", explain_syscall_setdomainname },
     /* FIXME: add support for setfsgid */
     /* FIXME: add support for setfsuid */
     /* FIXME: add support for setgid */
-    /* FIXME: add support for setgroups */
-    /* FIXME: add support for sethostname */
+    { "setgroups", explain_syscall_setgroups },
+    { "sethostname", explain_syscall_sethostname },
     /* FIXME: add support for setitimer */
     /* FIXME: add support for setlinebuf */
     /* FIXME: add support for set_mempolicy */
@@ -436,7 +477,7 @@ static const table_t table[] =
     /* FIXME: add support for sigaction */
     /* FIXME: add support for sigaltstack */
     /* FIXME: add support for signal */
-    /* FIXME: add support for signalfd */
+    { "signalfd", explain_syscall_signalfd },
     /* FIXME: add support for sigpending */
     /* FIXME: add support for sigprocmask */
     /* FIXME: add support for sigreturn */
@@ -451,9 +492,18 @@ static const table_t table[] =
     /* FIXME: add support for sscanf */
     /* FIXME: add support for ssetmask */
     { "stat", explain_syscall_stat },
-    /* FIXME: add support for statfs */
+    { "statfs", explain_syscall_statfs },
     /* FIXME: add support for stime */
+    { "strdup", explain_syscall_strdup },
     { "strerror", explain_syscall_strerror },
+    { "strndup", explain_syscall_strndup },
+    { "strtod", explain_syscall_strtod },
+    { "strtof", explain_syscall_strtof },
+    { "strtol", explain_syscall_strtol },
+    { "strtold", explain_syscall_strtold },
+    { "strtoll", explain_syscall_strtoll },
+    { "strtoul", explain_syscall_strtoul },
+    { "strtoull", explain_syscall_strtoull },
     /* FIXME: add support for stty */
     /* FIXME: add support for swapoff */
     /* FIXME: add support for swapon */
@@ -465,13 +515,22 @@ static const table_t table[] =
     /* FIXME: add support for syslog */
     { "system", explain_syscall_system },
     /* ----------  T  ------------------------------------------------------- */
+    { "tcdrain", explain_syscall_tcdrain },
+    { "tcflow", explain_syscall_tcflow },
+    { "tcflush", explain_syscall_tcflush },
+    { "tcgetattr", explain_syscall_tcgetattr },
+    { "tcsendbreak", explain_syscall_tcsendbreak },
+    { "tcsetattr", explain_syscall_tcsetattr },
     /* FIXME: add support for tee */
-    /* FIXME: add support for telldir */
+    { "telldir", explain_syscall_telldir },
     /* FIXME: add support for tempnam */
     /* FIXME: add support for tgkill */
-    /* FIXME: add support for time */
+    { "time", explain_syscall_time },
     /* FIXME: add support for timer_create */
     /* FIXME: add support for timer_delete */
+    { "timerfd_create", explain_syscall_timerfd_create },
+    /* FIXME: add support for timerfd_gettime */
+    /* FIXME: add support for timerfd_settime */
     /* FIXME: add support for timer_getoverrun */
     /* FIXME: add support for timer_gettime */
     /* FIXME: add support for timer_settime */
@@ -484,14 +543,13 @@ static const table_t table[] =
     /* ----------  U  ------------------------------------------------------- */
     /* FIXME: add support for ugetrlimit */
     /* FIXME: add support for ulimit */
-    /* FIXME: add support for umask */
     /* FIXME: add support for umount */
     /* FIXME: add support for uname */
     /* FIXME: add support for ungetc */
     { "unlink", explain_syscall_unlink },
     /* FIXME: add support for unshare */
     /* FIXME: add support for uselib */
-    /* FIXME: add support for ustat */
+    { "ustat", explain_syscall_ustat },
     { "utime", explain_syscall_utime },
     /* FIXME: add support for utimens */
     /* FIXME: add support for utimes */
@@ -510,11 +568,10 @@ static const table_t table[] =
     { "wait", explain_syscall_wait },
     { "wait3", explain_syscall_wait3 },
     { "wait4", explain_syscall_wait4 },
-    /* FIXME: add support for wait4 */
     /* FIXME: add support for waitid */
     { "waitpid", explain_syscall_waitpid },
     { "write", explain_syscall_write },
-    /* FIXME: add support for writev */
+    { "writev", explain_syscall_writev },
     /* ----------  X  ------------------------------------------------------- */
     /* ----------  Y  ------------------------------------------------------- */
     /* ----------  Z  ------------------------------------------------------- */
@@ -564,3 +621,10 @@ find_function(const char *name)
     exit(EXIT_FAILURE);
     return 0;
 }
+
+
+void
+syscall_statistics(int *total)
+{
+    *total = SIZEOF(table);
+}
