@@ -20,7 +20,7 @@
 #include <libexplain/ac/stdlib.h>
 
 #include <libexplain/closedir.h>
-#include <libexplain/strtol_or_die.h>
+#include <libexplain/strtol.h>
 #include <libexplain/wrap_and_print.h>
 
 #include <explain/syscall/closedir.h>
@@ -36,7 +36,7 @@ explain_syscall_closedir(int errnum, int argc, char **argv)
         fprintf(stderr, "closedir: requires 1 argument, not %d\n", argc);
         exit(EXIT_FAILURE);
     }
-    dir = (DIR *)explain_strtol_or_die(argv[0]);
+    dir = (DIR *)explain_strtol_or_die(argv[0], 0, 0);
 
     explain_wrap_and_print
     (
