@@ -20,7 +20,7 @@
 #include <libexplain/ac/stdlib.h>
 
 #include <libexplain/ftruncate.h>
-#include <libexplain/strtol_or_die.h>
+#include <libexplain/strtol.h>
 #include <libexplain/wrap_and_print.h>
 
 #include <explain/syscall/ftruncate.h>
@@ -37,8 +37,8 @@ explain_syscall_ftruncate(int errnum, int argc, char **argv)
         fprintf(stderr, "ftruncate: requires 2 arguments, not %d\n", argc);
         exit(EXIT_FAILURE);
     }
-    fildes = explain_strtol_or_die(argv[0]);
-    length = explain_strtol_or_die(argv[1]);
+    fildes = explain_strtol_or_die(argv[0], 0, 0);
+    length = explain_strtol_or_die(argv[1], 0, 0);
 
     explain_wrap_and_print
     (
