@@ -20,7 +20,7 @@
 #include <libexplain/ac/stdlib.h>
 
 #include <libexplain/truncate.h>
-#include <libexplain/strtol_or_die.h>
+#include <libexplain/strtol.h>
 #include <libexplain/wrap_and_print.h>
 
 #include <explain/syscall/truncate.h>
@@ -38,7 +38,7 @@ explain_syscall_truncate(int errnum, int argc, char **argv)
         exit(EXIT_FAILURE);
     }
     pathname = argv[0];
-    length = explain_strtol_or_die(argv[1]);
+    length = explain_strtol_or_die(argv[1], 0, 0);
 
     explain_wrap_and_print
     (
