@@ -43,4 +43,13 @@
 #define O_DIRECTORY 0x40000000
 #endif
 
+/*
+ * Even when O_LARGEFILE is not necessary, glibc adds one in for free.
+ * The trouble is that this make things interesting when decoding
+ * flags values returned by the kernel.
+ */
+#if defined(__linux__) && (O_LARGEFILE == 0)
+#define O_LARGEFILE_HIDDEN 0100000
+#endif
+
 #endif /* LIBEXPLAIN_AC_FCNTL_H */
