@@ -20,7 +20,7 @@
 #ifndef LIBEXPLAIN_AC_NET_ROUTE_H
 #define LIBEXPLAIN_AC_NET_ROUTE_H
 
-#include <libexplain/config.h>
+#include <libexplain/ac/sys/socket.h>
 
 #ifdef HAVE_NET_ROUTE_H
 #include <net/route.h>
