@@ -1,6 +1,6 @@
 /*
  * libexplain - Explain errno values returned by libc functions
- * Copyright (C) 2008 Peter Miller
+ * Copyright (C) 2008, 2009 Peter Miller
  * Written by Peter Miller <pmiller@opensource.org.au>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -20,7 +20,7 @@
 #ifndef LIBEXPLAIN_AC_SYS_TYPES_H
 #define LIBEXPLAIN_AC_SYS_TYPES_H
 
-#include <libexplain/config.h>
+#include <libexplain/ac/stddef.h>
 
 #ifdef HAVE_SYS_TYPES_H
 #include <sys/types.h>
