@@ -30,15 +30,9 @@ explain_accept_or_die(int fildes, struct sockaddr *sock_addr,
 {
     int             result;
 
-    result = accept(fildes, sock_addr, sock_addr_size);
+    result = explain_accept_on_error(fildes, sock_addr, sock_addr_size);
     if (result < 0)
     {
-        explain_program_name_assemble_internal(1);
-        explain_wrap_and_print
-        (
-            stderr,
-            explain_accept(fildes, sock_addr, sock_addr_size)
-        );
         exit(EXIT_FAILURE);
     }
     return result;
