@@ -29,10 +29,8 @@
 void
 explain_access_or_die(const char *pathname, int mode)
 {
-    if (access(pathname, mode) < 0)
+    if (explain_access_on_error(pathname, mode) < 0)
     {
-        explain_program_name_assemble_internal(1);
-        explain_wrap_and_print(stderr, explain_access(pathname, mode));
         exit(EXIT_FAILURE);
     }
 }
