@@ -36,4 +36,29 @@
 void explain_buffer_ebadf(explain_string_buffer_t *sb, int fildes,
     const char *caption);
 
+/**
+  * The explain_buffer_ebadf_stream function may be used to print a
+  * generic EBADF explanation into the string buffer.
+  *
+  * @param sb
+  *    The string buffer to print into
+  * @param caption
+  *    the argument name to whinge about
+  */
+void explain_buffer_ebadf_stream(explain_string_buffer_t *sb,
+    const char *caption);
+
+/**
+  * The explain_buffer_ebadf_dir function may be used to print a generic
+  * EBADF or EINVAL explanation into the string buffer, where a DIR*
+  * argument does not refer to a valid directory stream.
+  *
+  * @param sb
+  *    The string buffer to print into
+  * @param caption
+  *    the argument name to whinge about
+  */
+void explain_buffer_ebadf_dir(explain_string_buffer_t *sb,
+    const char *caption);
+
 #endif /* LIBEXPLAIN_BUFFER_EBADF_H */
