@@ -31,10 +31,12 @@
 #include <libexplain/buffer/enoent.h>
 #include <libexplain/buffer/enomem.h>
 #include <libexplain/buffer/enotdir.h>
+#include <libexplain/buffer/eperm.h>
 #include <libexplain/buffer/erofs.h>
 #include <libexplain/buffer/errno/chown.h>
 #include <libexplain/buffer/errno/generic.h>
 #include <libexplain/buffer/errno/path_resolution.h>
+#include <libexplain/buffer/file_type.h>
 #include <libexplain/buffer/gettext.h>
 #include <libexplain/buffer/gid.h>
 #include <libexplain/buffer/pointer.h>
@@ -256,18 +258,7 @@ explain_buffer_eperm_chown_vague(explain_string_buffer_t *sb, int owner,
     {
         if (group >= 0)
         {
-            explain_buffer_gettext
-            (
-                sb,
-                /*
-                 * xgettext: The message is used when explaining an EPERM
-                 * error reported by the chown(2) system call, in the case
-                 * where no more specific explanation is available,
-                 * but the call attempted to only the GID.
-                 */
-                i18n("the process did not have the required permissions "
-                "to change the group GID")
-            );
+            explain_buffer_eperm_setgid(sb);
         }
         else
         {
@@ -420,7 +411,8 @@ explain_buffer_eperm_chown_fd(explain_string_buffer_t *sb, int fildes,
 
 static void
 explain_buffer_errno_chown_explanation(explain_string_buffer_t *sb,
-    int errnum, const char *pathname, int owner, int group)
+    int errnum, const char *syscall_name, const char *pathname, int owner,
+    int group)
 {
     explain_final_t final_component;
 
@@ -431,6 +423,7 @@ explain_buffer_errno_chown_explanation(explain_string_buffer_t *sb,
     (
         sb,
         errnum,
+        syscall_name,
         pathname,
         owner,
         group,
@@ -439,10 +432,27 @@ explain_buffer_errno_chown_explanation(explain_string_buffer_t *sb,
 }
 
 
+static void
+explain_buffer_einval_chown(explain_string_buffer_t *sb)
+{
+    explain_buffer_gettext
+    (
+        sb,
+        /*
+         * xgettext: This error message is issued to explain an EINVAL error
+         * reported by a chown (or similar) system call, in the case where
+         * either the UID is invalid, the GID is invalid, or both.
+         */
+        i18n("the owner UID or group GID is not a value supported by the "
+        "system")
+    );
+}
+
+
 void
 explain_buffer_errno_chown_explanation_fc(explain_string_buffer_t *sb,
-    int errnum, const char *pathname, int owner, int group,
-    explain_final_t *final_component)
+    int errnum, const char *syscall_name, const char *pathname, int owner,
+    int group, explain_final_t *final_component)
 {
     final_component->want_to_modify_inode = 1;
 
@@ -461,15 +471,7 @@ explain_buffer_errno_chown_explanation_fc(explain_string_buffer_t *sb,
         break;
 
     case EINVAL:
-        explain_string_buffer_puts
-        (
-            sb,
-            /* FIXME: i18n */
-            "the owner UID or group GID is not a value supported by the "
-            "implementation; or, the fildes argument refers to a pipe or "
-            "socket and the implementation disallows execution of fchown() on "
-            "a pipe"
-        );
+        explain_buffer_einval_chown(sb);
         break;
 
     case ELOOP:
@@ -514,7 +516,7 @@ explain_buffer_errno_chown_explanation_fc(explain_string_buffer_t *sb,
         break;
 
     default:
-        explain_buffer_errno_generic(sb, errnum);
+        explain_buffer_errno_generic(sb, errnum, syscall_name);
         break;
     }
 }
@@ -522,7 +524,7 @@ explain_buffer_errno_chown_explanation_fc(explain_string_buffer_t *sb,
 
 void
 explain_buffer_errno_fchown_explanation(explain_string_buffer_t *sb,
-    int errnum, int fildes, int owner, int group)
+    int errnum, const char *syscall_name, int fildes, int owner, int group)
 {
     /*
      * http://www.opengroup.org/onlinepubs/009695399/functions/fchown.html
@@ -538,15 +540,57 @@ explain_buffer_errno_fchown_explanation(explain_string_buffer_t *sb,
         break;
 
     case EINVAL:
-        explain_string_buffer_puts
-        (
-            sb,
-            /* FIXME: i18n */
-            "the owner UID or group GID is not a value supported by the "
-            "implementation; or, the fildes argument refers to a pipe or "
-            "socket and the implementation disallows execution of fchown() on "
-            "a pipe"
-        );
+        {
+            struct stat     st;
+
+            if (fstat(fildes, &st) >= 0)
+            {
+                char            file_type[50];
+                explain_string_buffer_t file_type_buf;
+
+                switch (st.st_mode & S_IFMT)
+                {
+    #if S_IFREG != 0
+                case 0:
+    #endif
+                case S_IFSOCK:
+                case S_IFIFO:
+                    explain_string_buffer_init
+                    (
+                        &file_type_buf,
+                        file_type,
+                        sizeof(file_type)
+                    );
+                    explain_buffer_file_type(&file_type_buf, st.st_mode);
+                    explain_string_buffer_printf_gettext
+                    (
+                        sb,
+                        /*
+                         * xgettext: This error message is issued to explain
+                         * an EINVAL error reported by the chown (and similar)
+                         * system calls, in the case where the system call
+                         * cannot be applied to pipes or sockets.
+                         *
+                         * %1$s => The name of the offending argument
+                         * %2$s => The name of the file type (already
+                         *         translated)
+                         * %3$s => The name of the offending system call.
+                         */
+                        i18n("the %s argument refers to a %s and the system "
+                            "does not allow the %s system call to be applied "
+                            "to them"),
+                        "fildes",
+                        file_type,
+                        syscall_name
+                    );
+                    return;
+
+                default:
+                    break;
+                }
+            }
+        }
+        explain_buffer_einval_chown(sb);
         break;
 
     case ENOMEM:
@@ -562,7 +606,7 @@ explain_buffer_errno_fchown_explanation(explain_string_buffer_t *sb,
         break;
 
     default:
-        explain_buffer_errno_generic(sb, errnum);
+        explain_buffer_errno_generic(sb, errnum, syscall_name);
         break;
     }
 }
@@ -587,6 +631,7 @@ explain_buffer_errno_chown(explain_string_buffer_t *sb, int errnum,
     (
         &exp.explanation_sb,
         errnum,
+        "chown",
         pathname,
         owner,
         group
