@@ -24,13 +24,16 @@
 #include <libexplain/ac/unistd.h>
 
 #include <libexplain/buffer/dac.h>
+#include <libexplain/buffer/eexist.h>
 #include <libexplain/buffer/efault.h>
 #include <libexplain/buffer/einval.h>
+#include <libexplain/buffer/eisdir.h>
 #include <libexplain/buffer/eloop.h>
 #include <libexplain/buffer/emfile.h>
 #include <libexplain/buffer/enfile.h>
 #include <libexplain/buffer/enametoolong.h>
 #include <libexplain/buffer/enoent.h>
+#include <libexplain/buffer/enomedium.h>
 #include <libexplain/buffer/enomem.h>
 #include <libexplain/buffer/enotdir.h>
 #include <libexplain/buffer/erofs.h>
@@ -115,10 +118,8 @@ no_corresponding_device(explain_string_buffer_t *sb, const struct stat *st)
     (
         sb,
         /*
-         * xgettext: This message is used to explain
-         * an ENODEV error reported by an open(2)
-         * system call, and the device does not
-         * actually exist.
+         * xgettext: This message is used to explain an ENODEV error reported by
+         * an open(2) system call, and the device does not actually exist.
          *
          * %1$s => the file type of the special file,
          *         already translated.
@@ -134,9 +135,32 @@ no_corresponding_device(explain_string_buffer_t *sb, const struct stat *st)
 }
 
 
+static int
+is_device_file(const struct stat *st)
+{
+    switch (st->st_mode & S_IFMT)
+    {
+    case S_IFCHR:
+    case S_IFBLK:
+#ifdef S_IFMPC
+    case S_IFMPC:
+#endif
+#ifdef S_IFMPB
+   case S_IFMPB:
+#endif
+        return 1;
+
+    default:
+        break;
+    }
+    return 0;
+}
+
+
 void
 explain_buffer_errno_open_explanation(explain_string_buffer_t *sb,
-    int errnum, const char *pathname, int flags, int mode)
+    int errnum, const char *syscall_name, const char *pathname, int flags,
+    int mode)
 {
     explain_final_t final_component;
 
@@ -191,6 +215,44 @@ explain_buffer_errno_open_explanation(explain_string_buffer_t *sb,
             )
         )
         {
+            struct stat     st;
+
+            if
+            (
+                stat(pathname, &st) >= 0
+            &&
+                is_device_file(&st)
+            &&
+                explain_mount_point_nodev(&st)
+            )
+            {
+                explain_string_buffer_t file_type_sb;
+                char            file_type[50];
+
+                explain_string_buffer_init(&file_type_sb, file_type,
+                    sizeof(file_type));
+                explain_buffer_file_type(&file_type_sb, st.st_mode);
+                explain_string_buffer_printf_gettext
+                (
+                    sb,
+                    /*
+                     * xgettext:  This message is used when explaining an EACCES
+                     * error returned by an open(2) system call, in the case
+                     * where the file is a character special device or a block
+                     * special device, and the file system has been mounted with
+                     * the "nodev" option.
+                     *
+                     * %1$s => the file type (character sepcial device, etc)
+                     *         already translated.
+                     */
+                    i18n("the %s is on a file system mounted with the "
+                        "\"nodev\" option"),
+                    file_type
+                );
+                explain_buffer_mount_point_stat(sb, &st);
+                break;
+            }
+
             explain_buffer_gettext
             (
                 sb,
@@ -227,19 +289,7 @@ explain_buffer_errno_open_explanation(explain_string_buffer_t *sb,
             )
         )
         {
-            explain_buffer_gettext
-            (
-                sb,
-                /*
-                 * xgettext:  This message is used when explaining an
-                 * EEXIST error returned by an open(2) system call.
-                 * Usually path_resolution(7) will have a better
-                 * explanation, this explanation is only used when a
-                 * more specific explanation is not available.
-                 */
-                i18n("the file already exists when it should not (flags "
-                "O_CREAT and O_EXCL were used)")
-            );
+            explain_buffer_eexist(sb, pathname);
         }
         break;
 
@@ -247,6 +297,7 @@ explain_buffer_errno_open_explanation(explain_string_buffer_t *sb,
         explain_buffer_efault(sb, "pathname");
         break;
 
+#if defined(O_LARGEFILE) && (O_LARGEFILE != 0)
     case EFBIG:
     case EOVERFLOW:
         if (!(flags & O_LARGEFILE))
@@ -282,28 +333,15 @@ explain_buffer_errno_open_explanation(explain_string_buffer_t *sb,
             }
         }
         break;
+#endif
 
     case EISDIR:
         if ((flags & O_ACCMODE) != O_RDONLY)
         {
-            struct stat     st;
-
-            if (stat(pathname, &st) >= 0 && S_ISDIR(st.st_mode))
-            {
-                explain_buffer_gettext
-                (
-                    sb,
-                    /*
-                     * xgettext: This message is used to explain an EISDIR
-                     * reported by an open(2) system call.  You may not open
-                     * a directory for writing.
-                     */
-                    i18n("pathname refers to a directory and the access "
-                    "requested involved writing")
-                );
-            }
+            if (explain_buffer_eisdir(sb, pathname, "pathname"))
+                break;
         }
-        break;
+        goto generic;
 
     case ELOOP:
     case EMLINK: /* BSD */
@@ -355,6 +393,12 @@ explain_buffer_errno_open_explanation(explain_string_buffer_t *sb,
         explain_buffer_enoent(sb, pathname, "pathname", &final_component);
         break;
 
+#ifdef ENOMEDIUM
+    case ENOMEDIUM:
+        explain_buffer_enomedium(sb, pathname);
+        break;
+#endif
+
     case ENOMEM:
         explain_buffer_enomem_kernel(sb);
         break;
@@ -449,6 +493,7 @@ explain_buffer_errno_open_explanation(explain_string_buffer_t *sb,
         }
         break;
 
+#if defined(O_NOATIME) && (O_NOATIME != 0)
     case EPERM:
         if (flags & O_NOATIME)
         {
@@ -500,6 +545,7 @@ explain_buffer_errno_open_explanation(explain_string_buffer_t *sb,
             explain_buffer_dac_fowner(sb);
         }
         break;
+#endif
 
     case EROFS:
         explain_buffer_erofs(sb, pathname, "pathname");
@@ -579,12 +625,117 @@ explain_buffer_errno_open_explanation(explain_string_buffer_t *sb,
         break;
 
     default:
-        explain_buffer_errno_generic(sb, errnum);
+        generic:
+        explain_buffer_errno_generic(sb, errnum, syscall_name);
         break;
     }
+
+    if (flags & O_TRUNC)
+    {
+        if ((flags & O_ACCMODE) == O_RDONLY)
+        {
+            explain_string_buffer_puts(sb, "; ");
+            explain_buffer_gettext
+            (
+                sb,
+                /*
+                 * xgettext: This message is used to supplement an explanation
+                 * for an error reported by open(2) system call, in the case
+                 * where the caller used a flags combination with explicitly
+                 * undefined behavior.
+                 */
+                i18n("note that the behavior of (O_RDONLY | O_TRUNC) is "
+                    "undefined")
+            );
+        }
+        else
+        {
+            struct stat st;
+
+            if (stat(pathname, &st) >= 0)
+            {
+                explain_string_buffer_t file_type_sb;
+                char            file_type[50];
+
+                explain_string_buffer_init(&file_type_sb, file_type,
+                    sizeof(file_type));
+                explain_buffer_file_type(&file_type_sb, st.st_mode);
+
+                switch (st.st_mode & S_IFMT)
+                {
+                default:
+                    break;
+
+                case S_IFSOCK:
+                case S_IFIFO:
+                    /* explicitly ignored */
+                    {
+                        explain_string_buffer_puts(sb, "; ");
+                        explain_string_buffer_printf_gettext
+                        (
+                            sb,
+                            /*
+                             * xgettext: This message is used to supplement an
+                             * explanation for an error reported by open(2)
+                             * system call, in the case where the caller used
+                             * O_TRUNC in a combination that explicitly
+                             * ignores O_TRUNC.
+                             *
+                             * %1$s => the type of the special file, already
+                             *         translated
+                             */
+                            i18n("note that a %s will ignore the O_TRUNC flag"),
+                            file_type
+                        );
+                    }
+                    break;
+
+                case S_IFCHR:
+                    /*
+                     * The O_TRUNC flags is explicitly ignored for TTY devices,
+                     * but is undefined for all other character devices.  Since
+                     * we can't tell which case we have at this moment, we fall
+                     * through...
+                     */
+
+                case S_IFBLK:
+#ifdef S_IFMPC
+                case S_IFMPC:
+#endif
+#ifdef S_IFMPB
+                case S_IFMPB:
+#endif
+                    /* explicitly undefined */
+                    {
+                        explain_string_buffer_puts(sb, "; ");
+                        explain_string_buffer_printf_gettext
+                        (
+                            sb,
+                            /*
+                             * xgettext: This message is used to supplement an
+                             * explanation for an error reported by open(2)
+                             * system call, in the case where the caller used
+                             * O_TRUNC in a combination with explicitly
+                             * undefined behavior.
+                             *
+                             * %1$s => the type of the special file, already
+                             *         translated
+                             */
+                            i18n("note that the behavior of O_TRUNC on a %s is "
+                                "undefined"),
+                            file_type
+                        );
+                    }
+                    break;
+                }
+            }
+        }
+    }
+
     if ((flags & O_EXCL) && !(flags & O_CREAT))
     {
         explain_string_buffer_puts(sb, "; ");
+        /* FIXME: except for a TTY, where it means single open */
         explain_buffer_gettext
         (
             sb,
@@ -619,6 +770,7 @@ explain_buffer_errno_open(explain_string_buffer_t *sb, int errnum,
     (
         &exp.explanation_sb,
         errnum,
+        "open",
         pathname,
         flags,
         mode
