@@ -31,6 +31,7 @@
 #include <libexplain/buffer/caption_name_type.h>
 #include <libexplain/buffer/dac.h>
 #include <libexplain/buffer/does_not_have_inode_modify_permission.h>
+#include <libexplain/buffer/eexist.h>
 #include <libexplain/buffer/errno/path_resolution.h>
 #include <libexplain/buffer/file_type.h>
 #include <libexplain/buffer/gettext.h>
@@ -793,44 +794,6 @@ not_a_subdirectory(explain_string_buffer_t *sb, const char *comp,
 }
 
 
-static void
-must_not_exist(explain_string_buffer_t *sb, const char *comp,
-    int comp_st_mode, const char *caption, const char *dir, int dir_st_mode)
-{
-    char part1[NAME_MAX * 4 + 100];
-    explain_string_buffer_t part1_sb;
-    char part2[PATH_MAX * 4 + 100];
-    explain_string_buffer_t part2_sb;
-
-    explain_string_buffer_init(&part1_sb, part1, sizeof(part1));
-    explain_buffer_caption_name_type(&part1_sb, 0, comp, comp_st_mode);
-    explain_string_buffer_init(&part2_sb, part2, sizeof(part2));
-    explain_buffer_caption_name_type(&part2_sb, caption, dir, dir_st_mode);
-
-    explain_string_buffer_printf_gettext
-    (
-        sb,
-        /*
-         * xgettext: This message is used when directory has a directory
-         * entry for the named component, but a directory was expected
-         * and something else was there instead.
-         *
-         * Different language grammars may need to rearrange the parts.
-         *
-         * %1$s => The name of the offending path component and file
-         *         type (will never have slashes).  It will be quoted.
-         * %2$s => The name of the directory that contains the problematic
-         *         component; it may have zero, one or more slashes in it.  Will
-         *         include the name of the function call argument, the name of
-         *         the directory, and the file type "directory".
-         */
-        i18n("the %s in the %s should not exist yet"),
-        part1,
-        part2
-    );
-}
-
-
 static void
 wrong_file_type(explain_string_buffer_t *sb, const char *caption,
     const char *dir, int dir_st_mode, const char *comp, int comp_st_mode,
@@ -1598,7 +1561,9 @@ explain_buffer_errno_path_resolution(explain_string_buffer_t *sb,
                     sizeof(intermediate_path)
                 );
                 if (rlb[0] == '/')
+                {
                     explain_string_buffer_puts(&intermediate_path_buf, rlb);
+                }
                 else
                 {
                     explain_string_buffer_puts
@@ -1634,8 +1599,8 @@ explain_buffer_errno_path_resolution(explain_string_buffer_t *sb,
 
                 if (rlb[0] == '/')
                 {
-                    lookup_directory_buf.position = 1;
-                    lookup_directory[0] = '/';
+                    explain_string_buffer_rewind(&lookup_directory_buf);
+                    explain_string_buffer_putc(&lookup_directory_buf, '/');
                 }
                 ++number_of_symlinks_followed;
                 if (number_of_symlinks_followed >= symloop_max)
@@ -1710,12 +1675,11 @@ explain_buffer_errno_path_resolution(explain_string_buffer_t *sb,
          */
         if (final_component->must_not_exist)
         {
-            must_not_exist
+            explain_buffer_eexist5
             (
                 sb,
                 component,
                 intermediate_path_st.st_mode,
-                caption,
                 lookup_directory,
                 lookup_directory_st.st_mode
             );
