@@ -131,7 +131,8 @@ dir_vs_not_dir2(explain_string_buffer_t *sb, const char *dir_caption,
 
 static void
 explain_buffer_errno_rename_explanation(explain_string_buffer_t *sb,
-    int errnum, const char *oldpath, const char *newpath)
+    int errnum, const char *syscall_name, const char *oldpath,
+    const char *newpath)
 {
     explain_final_t oldpath_final_component;
     explain_final_t newpath_final_component;
@@ -250,7 +251,7 @@ explain_buffer_errno_rename_explanation(explain_string_buffer_t *sb,
             i18n("oldpath or newpath is a directory that is in use "
             "by some process (perhaps as current working directory, "
             "or as root directory, or it was open for reading) or is "
-            "in use by the system (for example as mount point)")
+            "in use by the system (for example as a mount point)")
         );
         break;
 
@@ -533,11 +534,11 @@ explain_buffer_errno_rename_explanation(explain_string_buffer_t *sb,
         break;
 
     case EXDEV:
-        explain_buffer_exdev(sb, oldpath, newpath, "rename");
+        explain_buffer_exdev(sb, oldpath, newpath, syscall_name);
         break;
 
     default:
-        explain_buffer_errno_generic(sb, errnum);
+        explain_buffer_errno_generic(sb, errnum, syscall_name);
         break;
     }
 
@@ -567,6 +568,7 @@ explain_buffer_errno_rename(explain_string_buffer_t *sb, int errnum,
     (
         &exp.explanation_sb,
         errnum,
+        "rename",
         oldpath,
         newpath
     );
