@@ -28,6 +28,13 @@ explain_buffer_int(explain_string_buffer_t *sb, int data)
 }
 
 
+void
+explain_buffer_uint(explain_string_buffer_t *sb, unsigned data)
+{
+    explain_string_buffer_printf(sb, "%u", data);
+}
+
+
 void
 explain_buffer_int_star(explain_string_buffer_t *sb, const int *data)
 {
@@ -40,3 +47,17 @@ explain_buffer_int_star(explain_string_buffer_t *sb, const int *data)
         explain_string_buffer_puts(sb, " }");
     }
 }
+
+
+void
+explain_buffer_one_char_star(explain_string_buffer_t *sb, const char *data)
+{
+    if (explain_pointer_is_efault(data, sizeof(*data)))
+        explain_buffer_pointer(sb, data);
+    else
+    {
+        explain_string_buffer_puts(sb, "{ ");
+        explain_buffer_int(sb, *data);
+        explain_string_buffer_puts(sb, " }");
+    }
+}
