@@ -32,6 +32,17 @@
   */
 void explain_buffer_int(explain_string_buffer_t *sb, int value);
 
+/**
+  * The explain_buffer_int function may be used to print an unsigned
+  * integer value.
+  *
+  * @param sb
+  *    The string buffer to print into.
+  * @param value
+  *    The value to be printed.
+  */
+void explain_buffer_uint(explain_string_buffer_t *sb, unsigned value);
+
 /**
   * The explain_buffer_int_star function may be used to print an integer
   * value.
@@ -44,4 +55,16 @@ void explain_buffer_int(explain_string_buffer_t *sb, int value);
 void explain_buffer_int_star(explain_string_buffer_t *sb,
     const int *value);
 
+/**
+  * The explain_buffer_one_char_star function may be used to print an integer
+  * value from a single signed byte.
+  *
+  * @param sb
+  *    The string buffer to print into.
+  * @param value
+  *    a pointer to the value to be printed.
+  */
+void explain_buffer_one_char_star(explain_string_buffer_t *sb,
+    const char *value);
+
 #endif /* LIBEXPLAIN_BUFFER_INT_H */
