@@ -31,9 +31,15 @@ explain_buffer_pointer(explain_string_buffer_t *sb, const void *ptr)
     {
         /*
          * Some old systems don't have %p, and some new systems format
-         * %p differently than glibc.  If this is an issue, we will
-         * look at some ./configure magic to cope.
+         * %p differently than glibc.  Use consistent formatting, it
+         * makes the automated tests easier to write.
          */
+#if SIZEOF_VOID_P > SIZEOF_LONG
+        explain_string_buffer_printf(sb, "0x%08llX", (unsigned long long)ptr);
+#elif SIZEOF_VOID_P > SIZEOF_INT
         explain_string_buffer_printf(sb, "0x%08lX", (unsigned long)ptr);
+#else
+        explain_string_buffer_printf(sb, "0x%08X", (unsigned)ptr);
+#endif
     }
 }
