@@ -28,10 +28,8 @@
 void
 explain_chdir_or_die(const char * pathname)
 {
-    if (chdir(pathname) < 0)
+    if (explain_chdir_on_error(pathname) < 0)
     {
-        explain_program_name_assemble_internal(1);
-        explain_wrap_and_print(stderr, explain_chdir(pathname));
         exit(EXIT_FAILURE);
     }
 }
