@@ -29,10 +29,8 @@
 void
 explain_chmod_or_die(const char *pathname, int mode)
 {
-    if (chmod(pathname, mode))
+    if (explain_chmod_on_error(pathname, mode))
     {
-        explain_program_name_assemble_internal(1);
-        explain_wrap_and_print(stderr, explain_chmod(pathname, mode));
         exit(EXIT_FAILURE);
     }
 }
