@@ -28,10 +28,8 @@
 void
 explain_chown_or_die(const char *path, int owner, int group)
 {
-    if (chown(path, owner, group) < 0)
+    if (explain_chown_on_error(path, owner, group) < 0)
     {
-        explain_program_name_assemble_internal(1);
-        explain_wrap_and_print(stderr, explain_chown(path, owner, group));
         exit(EXIT_FAILURE);
     }
 }
