@@ -28,10 +28,8 @@
 void
 explain_close_or_die(int fildes)
 {
-    if (close(fildes) < 0)
+    if (explain_close_on_error(fildes) < 0)
     {
-        explain_program_name_assemble_internal(1);
-        explain_wrap_and_print(stderr, explain_close(fildes));
         exit(EXIT_FAILURE);
     }
 }
