@@ -27,10 +27,8 @@
 void
 explain_closedir_or_die(DIR *dir)
 {
-    if (closedir(dir) < 0)
+    if (explain_closedir_on_error(dir) < 0)
     {
-        explain_program_name_assemble_internal(1);
-        explain_wrap_and_print(stderr, explain_closedir(dir));
         exit(EXIT_FAILURE);
     }
 }
