@@ -29,14 +29,8 @@ void
 explain_connect_or_die(int fildes, const struct sockaddr *serv_addr,
     int serv_addr_size)
 {
-    if (connect(fildes, serv_addr, serv_addr_size) < 0)
+    if (explain_connect_on_error(fildes, serv_addr, serv_addr_size) < 0)
     {
-        explain_program_name_assemble_internal(1);
-        explain_wrap_and_print
-        (
-            stderr,
-            explain_connect(fildes, serv_addr, serv_addr_size)
-        );
         exit(EXIT_FAILURE);
     }
 }
