@@ -30,11 +30,9 @@ explain_creat_or_die(const char *pathname, int mode)
 {
     int             fildes;
 
-    fildes = creat(pathname, mode);
+    fildes = explain_creat_on_error(pathname, mode);
     if (fildes < 0)
     {
-        explain_program_name_assemble_internal(1);
-        explain_wrap_and_print(stderr, explain_creat(pathname, mode));
         exit(EXIT_FAILURE);
     }
     return fildes;
