@@ -28,10 +28,8 @@
 void
 explain_dup2_or_die(int oldfd, int newfd)
 {
-    if (dup2(oldfd, newfd) < 0)
+    if (explain_dup2_on_error(oldfd, newfd) < 0)
     {
-        explain_program_name_assemble_internal(1);
-        explain_wrap_and_print(stderr, explain_dup2(oldfd, newfd));
         exit(EXIT_FAILURE);
     }
 }
