@@ -30,11 +30,9 @@ explain_dup_or_die(int fildes)
 {
     int             result;
 
-    result = dup(fildes);
+    result = explain_dup_on_error(fildes);
     if (result < 0)
     {
-        explain_program_name_assemble_internal(1);
-        explain_wrap_and_print(stderr, explain_dup(fildes));
         exit(EXIT_FAILURE);
     }
     return result;
