@@ -23,7 +23,7 @@
 
 
 const char *
-explain_errno_fread(int errnum, void *ptr, long size, long nmemb, FILE *fp)
+explain_errno_fread(int errnum, void *ptr, size_t size, size_t nmemb, FILE *fp)
 {
     explain_message_errno_fread
     (
