@@ -28,10 +28,8 @@
 void
 explain_execvp_or_die(const char *pathname, char *const *argv)
 {
-    if (execvp(pathname, argv) < 0)
+    if (explain_execvp_on_error(pathname, argv) < 0)
     {
-        explain_program_name_assemble_internal(1);
-        explain_wrap_and_print(stderr, explain_execvp(pathname, argv));
         exit(EXIT_FAILURE);
     }
 }
