@@ -29,10 +29,8 @@
 void
 explain_fchdir_or_die(int fildes)
 {
-    if (fchdir(fildes) < 0)
+    if (explain_fchdir_on_error(fildes) < 0)
     {
-        explain_program_name_assemble_internal(1);
-        explain_wrap_and_print(stderr, explain_fchdir(fildes));
         exit(EXIT_FAILURE);
     }
 }
