@@ -29,10 +29,8 @@
 void
 explain_fchmod_or_die(int fildes, int mode)
 {
-    if (fchmod(fildes, mode) < 0)
+    if (explain_fchmod_on_error(fildes, mode) < 0)
     {
-        explain_program_name_assemble_internal(1);
-        explain_wrap_and_print(stderr, explain_fchmod(fildes, mode));
         exit(EXIT_FAILURE);
     }
 }
