@@ -28,14 +28,8 @@
 void
 explain_fchown_or_die(int fildes, int owner, int group)
 {
-    if (fchown(fildes, owner, group) < 0)
+    if (explain_fchown_on_error(fildes, owner, group) < 0)
     {
-        explain_program_name_assemble_internal(1);
-        explain_wrap_and_print
-        (
-            stderr,
-            explain_fchown(fildes, owner, group)
-        );
         exit(EXIT_FAILURE);
     }
 }
