@@ -28,10 +28,8 @@
 void
 explain_fclose_or_die(FILE *fp)
 {
-    if (fflush(fp) || fclose(fp))
+    if (explain_fclose_on_error(fp))
     {
-        explain_program_name_assemble_internal(1);
-        explain_wrap_and_print(stderr, explain_fclose(fp));
         exit(EXIT_FAILURE);
     }
 }
