@@ -30,15 +30,9 @@ explain_fcntl_or_die(int fildes, int command, long arg)
 {
     int             result;
 
-    result = fcntl(fildes, command, arg);
+    result = explain_fcntl_on_error(fildes, command, arg);
     if (result < 0)
     {
-        explain_program_name_assemble_internal(1);
-        explain_wrap_and_print
-        (
-            stderr,
-            explain_fcntl(fildes, command, arg)
-        );
         exit(EXIT_FAILURE);
     }
     return result;
