@@ -29,11 +29,9 @@ explain_fdopen_or_die(int fildes, const char *mode)
 {
     FILE            *fp;
 
-    fp = fdopen(fildes, mode);
+    fp = explain_fdopen_on_error(fildes, mode);
     if (!fp)
     {
-        explain_program_name_assemble_internal(1);
-        explain_wrap_and_print(stderr, explain_fdopen(fildes, mode));
         exit(EXIT_FAILURE);
     }
     return fp;
