@@ -27,10 +27,8 @@
 void
 explain_ferror_or_die(FILE *fp)
 {
-    if (ferror(fp))
+    if (explain_ferror_on_error(fp))
     {
-        explain_program_name_assemble_internal(1);
-        explain_wrap_and_print(stderr, explain_ferror(fp));
         exit(EXIT_FAILURE);
     }
 }
