@@ -29,15 +29,9 @@ explain_fgets_or_die(char *data, int data_size, FILE *fp)
 {
     char            *result;
 
-    result = fgets(data, data_size, fp);
+    result = explain_fgets_on_error(data, data_size, fp);
     if (!result && ferror(fp))
     {
-        explain_program_name_assemble_internal(1);
-        explain_wrap_and_print
-        (
-            stderr,
-            explain_fgets(data, data_size, fp)
-        );
         exit(EXIT_FAILURE);
     }
     return result;
