@@ -33,5 +33,5 @@ explain_fildes_to_address_family(int fildes)
     sa_size = sizeof(ss);
     if (getsockname(fildes, sa, &sa_size) < 0)
         return -1;
-    return sa->sa_family;
+    return ss.ss_family;
 }
