@@ -29,11 +29,9 @@ explain_fopen_or_die(const char *pathname, const char *flags)
 {
     FILE            *fp;
 
-    fp = fopen(pathname, flags);
+    fp = explain_fopen_on_error(pathname, flags);
     if (!fp)
     {
-        explain_program_name_assemble_internal(1);
-        explain_wrap_and_print(stderr, explain_fopen(pathname, flags));
         exit(EXIT_FAILURE);
     }
     return fp;
