@@ -30,11 +30,9 @@ explain_fork_or_die(void)
 {
     int             result;
 
-    result = fork();
+    result = explain_fork_on_error();
     if (result < 0)
     {
-        explain_program_name_assemble_internal(1);
-        explain_wrap_and_print(stderr, explain_fork());
         exit(EXIT_FAILURE);
     }
     return result;
