@@ -32,11 +32,9 @@ explain_fpathconf_or_die(int fildes, int name)
     long            result;
 
     errno = 0;
-    result = fpathconf(fildes, name);
+    result = explain_fpathconf_on_error(fildes, name);
     if (result == -1 && errno != 0)
     {
-        explain_program_name_assemble_internal(1);
-        explain_wrap_and_print(stderr, explain_fpathconf(fildes, name));
         exit(EXIT_FAILURE);
     }
     return result;
