@@ -27,10 +27,8 @@
 void
 explain_fputc_or_die(int c, FILE *fp)
 {
-    if (fputc(c, fp) < 0)
+    if (explain_fputc_on_error(c, fp) < 0)
     {
-        explain_program_name_assemble_internal(1);
-        explain_wrap_and_print(stderr, explain_fputc(c, fp));
         exit(EXIT_FAILURE);
     }
 }
