@@ -22,7 +22,7 @@
 
 
 const char *
-explain_fread(void *ptr, long size, long nmemb, FILE *fp)
+explain_fread(void *ptr, size_t size, size_t nmemb, FILE *fp)
 {
     return explain_errno_fread(errno, ptr, size, nmemb, fp);
 }
