@@ -27,14 +27,8 @@
 void
 explain_freopen_or_die(const char *pathname, const char *flags, FILE *fp)
 {
-    if (!freopen(pathname, flags, fp))
+    if (!explain_freopen_on_error(pathname, flags, fp))
     {
-        explain_program_name_assemble_internal(1);
-        explain_wrap_and_print
-        (
-            stderr,
-            explain_freopen(pathname, flags, fp)
-        );
         exit(EXIT_FAILURE);
     }
 }
