@@ -28,10 +28,8 @@
 void
 explain_fstat_or_die(int fildes, struct stat *buf)
 {
-    if (fstat(fildes, buf) < 0)
+    if (explain_fstat_on_error(fildes, buf) < 0)
     {
-        explain_program_name_assemble_internal(1);
-        explain_wrap_and_print(stderr, explain_fstat(fildes, buf));
         exit(EXIT_FAILURE);
     }
 }
