@@ -28,10 +28,8 @@
 void
 explain_ftruncate_or_die(int fildes, long long length)
 {
-    if (ftruncate(fildes, length) < 0)
+    if (explain_ftruncate_on_error(fildes, length) < 0)
     {
-        explain_program_name_assemble_internal(1);
-        explain_wrap_and_print(stderr, explain_ftruncate(fildes, length));
         exit(EXIT_FAILURE);
     }
 }
