@@ -28,10 +28,8 @@
 void
 explain_futimes_or_die(int fildes, const struct timeval *tv)
 {
-    if (futimes(fildes, tv) < 0)
+    if (explain_futimes_on_error(fildes, tv) < 0)
     {
-        explain_program_name_assemble_internal(1);
-        explain_wrap_and_print(stderr, explain_futimes(fildes, tv));
         exit(EXIT_FAILURE);
     }
 }
