@@ -29,15 +29,9 @@ explain_fwrite_or_die(const void *ptr, size_t size, size_t nmemb, FILE *fp)
 {
     size_t          result;
 
-    result = fwrite(ptr, size, nmemb, fp);
+    result = explain_fwrite_on_error(ptr, size, nmemb, fp);
     if (result < nmemb)
     {
-        explain_program_name_assemble_internal(1);
-        explain_wrap_and_print
-        (
-            stderr,
-            explain_fwrite(ptr, size, nmemb, fp)
-        );
         exit(EXIT_FAILURE);
     }
     return result;
