@@ -29,11 +29,9 @@ explain_getcwd_or_die(char *data, size_t data_size)
 {
     char            *result;
 
-    result = getcwd(data, data_size);
+    result = explain_getcwd_on_error(data, data_size);
     if (!result)
     {
-        explain_program_name_assemble_internal(1);
-        explain_wrap_and_print(stderr, explain_getcwd(data, data_size));
         exit(EXIT_FAILURE);
     }
     return result;
