@@ -28,14 +28,8 @@ void
 explain_getpeername_or_die(int fildes, struct sockaddr *sock_addr,
     socklen_t *sock_addr_size)
 {
-    if (getpeername(fildes, sock_addr, sock_addr_size) < 0)
+    if (explain_getpeername_on_error(fildes, sock_addr, sock_addr_size) < 0)
     {
-        explain_program_name_assemble_internal(1);
-        explain_wrap_and_print
-        (
-            stderr,
-            explain_getpeername(fildes, sock_addr, sock_addr_size)
-        );
         exit(EXIT_FAILURE);
     }
 }
