@@ -28,10 +28,8 @@
 void
 explain_getrlimit_or_die(int resource, struct rlimit *rlim)
 {
-    if (getrlimit(resource, rlim) < 0)
+    if (explain_getrlimit_on_error(resource, rlim) < 0)
     {
-        explain_program_name_assemble_internal(1);
-        explain_wrap_and_print(stderr, explain_getrlimit(resource, rlim));
         exit(EXIT_FAILURE);
     }
 }
