@@ -28,14 +28,8 @@ void
 explain_getsockopt_or_die(int fildes, int level, int name, void *data,
     socklen_t *data_size)
 {
-    if (getsockopt(fildes, level, name, data, data_size) < 0)
+    if (explain_getsockopt_on_error(fildes, level, name, data, data_size) < 0)
     {
-        explain_program_name_assemble_internal(1);
-        explain_wrap_and_print
-        (
-            stderr,
-            explain_getsockopt(fildes, level, name, data, data_size)
-        );
         exit(EXIT_FAILURE);
     }
 }
