@@ -28,10 +28,8 @@
 void
 explain_gettimeofday_or_die(struct timeval *tv, struct timezone *tz)
 {
-    if (gettimeofday(tv, tz) < 0)
+    if (explain_gettimeofday_on_error(tv, tz) < 0)
     {
-        explain_program_name_assemble_internal(1);
-        explain_wrap_and_print(stderr, explain_gettimeofday(tv, tz));
         exit(EXIT_FAILURE);
     }
 }
