@@ -43,4 +43,7 @@ const explain_iocontrol_t explain_iocontrol_fioasync =
     0, /* print_name */
     print_data,
     0, /* print_explanation */
+    0, /* print_data_returned */
+    __FILE__,
+    __LINE__,
 };
