@@ -17,6 +17,7 @@
  * with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include <libexplain/ac/sys/filio.h>
 #include <libexplain/ac/sys/socket.h>
 
 #include <libexplain/iocontrol/fiogetown.h>
@@ -30,4 +31,7 @@ const explain_iocontrol_t explain_iocontrol_fiogetown =
     0, /* print_name */
     0, /* print_data */
     0, /* print_explanation */
+    0, /* print_data_returned */
+    __FILE__,
+    __LINE__,
 };
