@@ -30,4 +30,7 @@ const explain_iocontrol_t explain_iocontrol_fionclex =
     0, /* print_name */
     0, /* print_data */
     0, /* print_explanation */
+    0, /* print_data_returned */
+    __FILE__,
+    __LINE__,
 };
