@@ -18,6 +18,7 @@
  */
 
 #include <libexplain/ac/sys/ioctl.h>
+#include <libexplain/ac/sys/stat.h>
 
 #include <libexplain/buffer/int.h>
 #include <libexplain/iocontrol/fionread.h>
@@ -35,12 +36,43 @@ print_data(const explain_iocontrol_t *p, explain_string_buffer_t *sb,
 }
 
 
+static int
+disambiguate(int fildes, int request, const void *data)
+{
+    struct stat     st;
+
+    /* success = 0, failure = -1 */
+    (void)request;
+    (void)data;
+    if (fstat(fildes, &st) < 0)
+        return 0; /* "everything else" */
+    switch (st.st_mode & S_IFMT)
+    {
+    case S_IFSOCK:
+    case S_IFCHR:
+        return -1;
+
+    default:
+        return 0;
+    }
+}
+
+
+/*
+ * We have conflicts:
+ * SIOCINQ -- sockets only
+ * TIOCINQ -- terminals only
+ * FIONREAD -- everything else
+ */
 const explain_iocontrol_t explain_iocontrol_fionread =
 {
     "FIONREAD", /* name */
     FIONREAD, /* value */
-    0, /* disambiguate */
+    disambiguate,
     0, /* print_name */
     print_data,
     0, /* print_explanation */
+    0, /* print_data_returned */
+    __FILE__,
+    __LINE__,
 };
