@@ -17,6 +17,7 @@
  * with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include <libexplain/ac/sys/filio.h>
 #include <libexplain/ac/sys/socket.h>
 
 #include <libexplain/buffer/int.h>
@@ -43,4 +44,7 @@ const explain_iocontrol_t explain_iocontrol_fiosetown =
     0, /* print_name */
     print_data,
     0, /* print_explanation */
+    0, /* print_data_returned */
+    __FILE__,
+    __LINE__,
 };
