@@ -22,9 +22,7 @@
 #include <libexplain/iocontrol/gio_scrnmap.h>
 
 
-#ifndef GIO_SCRNMAP
-#define GIO_SCRNMAP -1
-#endif
+#ifdef GIO_SCRNMAP
 
 const explain_iocontrol_t explain_iocontrol_gio_scrnmap =
 {
@@ -34,4 +32,24 @@ const explain_iocontrol_t explain_iocontrol_gio_scrnmap =
     0, /* print_name */
     0, /* print_data */
     0, /* print_explanation */
+    0, /* print_data_returned */
+    __FILE__,
+    __LINE__,
 };
+
+#else
+
+const explain_iocontrol_t explain_iocontrol_gio_scrnmap =
+{
+    0, /* name */
+    0, /* value */
+    0, /* disambiguate */
+    0, /* print_name */
+    0, /* print_data */
+    0, /* print_explanation */
+    0, /* print_data_returned */
+    __FILE__,
+    __LINE__,
+};
+
+#endif
