@@ -22,9 +22,7 @@
 #include <libexplain/iocontrol/gio_uniscrnmap.h>
 
 
-#ifndef GIO_UNISCRNMAP
-#define GIO_UNISCRNMAP -1
-#endif
+#ifdef GIO_UNISCRNMAP
 
 const explain_iocontrol_t explain_iocontrol_gio_uniscrnmap =
 {
@@ -34,4 +32,24 @@ const explain_iocontrol_t explain_iocontrol_gio_uniscrnmap =
     0, /* print_name */
     0, /* print_data */
     0, /* print_explanation */
+    0, /* print_data_returned */
+    __FILE__,
+    __LINE__,
 };
+
+#else
+
+const explain_iocontrol_t explain_iocontrol_gio_uniscrnmap =
+{
+    0, /* name */
+    0, /* value */
+    0, /* disambiguate */
+    0, /* print_name */
+    0, /* print_data */
+    0, /* print_explanation */
+    0, /* print_data_returned */
+    __FILE__,
+    __LINE__,
+};
+
+#endif
