@@ -17,14 +17,13 @@
  * with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include <libexplain/ac/sys/ioctl.h>
 #include <libexplain/ac/sys/mtio.h>
 
 #include <libexplain/iocontrol/mtiocget.h>
 
 
-#ifndef MTIOCGET
-#define MTIOCGET -1
-#endif
+#ifdef MTIOCGET
 
 const explain_iocontrol_t explain_iocontrol_mtiocget =
 {
@@ -34,4 +33,24 @@ const explain_iocontrol_t explain_iocontrol_mtiocget =
     0, /* print_name */
     0, /* print_data */
     0, /* print_explanation */
+    0, /* print_data_returned */
+    __FILE__,
+    __LINE__,
 };
+
+#else
+
+const explain_iocontrol_t explain_iocontrol_mtiocget =
+{
+    0, /* name */
+    0, /* value */
+    0, /* disambiguate */
+    0, /* print_name */
+    0, /* print_data */
+    0, /* print_explanation */
+    0, /* print_data_returned */
+    __FILE__,
+    __LINE__,
+};
+
+#endif
