@@ -23,9 +23,7 @@
 #include <libexplain/iocontrol/pio_cmap.h>
 
 
-#ifndef PIO_CMAP
-#define PIO_CMAP -1
-#endif
+#ifdef PIO_CMAP
 
 const explain_iocontrol_t explain_iocontrol_pio_cmap =
 {
@@ -35,4 +33,24 @@ const explain_iocontrol_t explain_iocontrol_pio_cmap =
     0, /* print_name */
     0, /* print_data */
     0, /* print_explanation */
+    0, /* print_data_returned */
+    __FILE__,
+    __LINE__,
 };
+
+#else
+
+const explain_iocontrol_t explain_iocontrol_pio_cmap =
+{
+    0, /* name */
+    0, /* value */
+    0, /* disambiguate */
+    0, /* print_name */
+    0, /* print_data */
+    0, /* print_explanation */
+    0, /* print_data_returned */
+    __FILE__,
+    __LINE__,
+};
+
+#endif
