@@ -18,6 +18,7 @@
  */
 
 #include <libexplain/ac/sys/socket.h>
+#include <libexplain/ac/sys/sockio.h>
 
 #include <libexplain/iocontrol/siocatmark.h>
 
@@ -30,4 +31,7 @@ const explain_iocontrol_t explain_iocontrol_siocatmark =
     0, /* print_name */
     0, /* print_data */
     0, /* print_explanation */
+    0, /* print_data_returned */
+    __FILE__,
+    __LINE__,
 };
