@@ -18,15 +18,14 @@
  */
 
 #include <libexplain/ac/linux/sockios.h>
+#include <libexplain/ac/sys/sockio.h>
 
 #include <libexplain/buffer/pointer.h>
 #include <libexplain/iocontrol/siocgifcount.h>
 #include <libexplain/path_is_efault.h>
 
 
-#ifndef SIOCGIFCOUNT
-#define SIOCGIFCOUNT -1
-#endif
+#ifdef SIOCGIFCOUNT
 
 const explain_iocontrol_t explain_iocontrol_siocgifcount =
 {
@@ -36,4 +35,24 @@ const explain_iocontrol_t explain_iocontrol_siocgifcount =
     0, /* print_name */
     0, /* print_data */
     0, /* print_explanation */
+    0, /* print_data_returned */
+    __FILE__,
+    __LINE__,
 };
+
+#else
+
+const explain_iocontrol_t explain_iocontrol_siocgifcount =
+{
+    0, /* name */
+    0, /* value */
+    0, /* disambiguate */
+    0, /* print_name */
+    0, /* print_data */
+    0, /* print_explanation */
+    0, /* print_data_returned */
+    __FILE__,
+    __LINE__,
+};
+
+#endif
