@@ -18,13 +18,12 @@
  */
 
 #include <libexplain/ac/linux/sockios.h>
+#include <libexplain/ac/sys/sockio.h>
 
 #include <libexplain/iocontrol/siocgifencap.h>
 
 
-#ifndef SIOCGIFENCAP
-#define SIOCGIFENCAP -1
-#endif
+#ifdef SIOCGIFENCAP
 
 const explain_iocontrol_t explain_iocontrol_siocgifencap =
 {
@@ -34,4 +33,24 @@ const explain_iocontrol_t explain_iocontrol_siocgifencap =
     0, /* print_name */
     0, /* print_data */
     0, /* print_explanation */
+    0, /* print_data_returned */
+    __FILE__,
+    __LINE__,
 };
+
+#else
+
+const explain_iocontrol_t explain_iocontrol_siocgifencap =
+{
+    0, /* name */
+    0, /* value */
+    0, /* disambiguate */
+    0, /* print_name */
+    0, /* print_data */
+    0, /* print_explanation */
+    0, /* print_data_returned */
+    __FILE__,
+    __LINE__,
+};
+
+#endif
