@@ -18,10 +18,13 @@
  */
 
 #include <libexplain/ac/sys/socket.h>
+#include <libexplain/ac/sys/sockio.h>
 
 #include <libexplain/iocontrol/siocgstamp.h>
 
 
+#ifdef SIOCGSTAMP
+
 const explain_iocontrol_t explain_iocontrol_siocgstamp =
 {
     "SIOCGSTAMP", /* name */
@@ -30,4 +33,24 @@ const explain_iocontrol_t explain_iocontrol_siocgstamp =
     0, /* print_name */
     0, /* print_data */
     0, /* print_explanation */
+    0, /* print_data_returned */
+    __FILE__,
+    __LINE__,
 };
+
+#else
+
+const explain_iocontrol_t explain_iocontrol_siocgstamp =
+{
+    0, /* name */
+    0, /* value */
+    0, /* disambiguate */
+    0, /* print_name */
+    0, /* print_data */
+    0, /* print_explanation */
+    0, /* print_data_returned */
+    __FILE__,
+    __LINE__,
+};
+
+#endif
