@@ -18,15 +18,14 @@
  */
 
 #include <libexplain/ac/sys/socket.h>
+#include <libexplain/ac/sys/sockio.h>
 
 #include <libexplain/buffer/pointer.h>
 #include <libexplain/iocontrol/siocgstampns.h>
 #include <libexplain/path_is_efault.h>
 
 
-#ifndef SIOCGSTAMPNS
-#define SIOCGSTAMPNS -1
-#endif
+#ifdef SIOCGSTAMPNS
 
 const explain_iocontrol_t explain_iocontrol_siocgstampns =
 {
@@ -36,4 +35,24 @@ const explain_iocontrol_t explain_iocontrol_siocgstampns =
     0, /* print_name */
     0, /* print_data */
     0, /* print_explanation */
+    0, /* print_data_returned */
+    __FILE__,
+    __LINE__,
 };
+
+#else
+
+const explain_iocontrol_t explain_iocontrol_siocgstampns =
+{
+    0, /* name */
+    0, /* value */
+    0, /* disambiguate */
+    0, /* print_name */
+    0, /* print_data */
+    0, /* print_explanation */
+    0, /* print_data_returned */
+    __FILE__,
+    __LINE__,
+};
+
+#endif
