@@ -23,29 +23,41 @@
 
 #include <libexplain/iocontrol/siocinq.h>
 
-
-#ifndef SIOCINQ
-#define SIOCINQ -1
-#endif
-
-
-static int
-disambiguate(int fildes, int request, const void *data)
-{
-    struct stat     st;
-
-    (void)request;
-    (void)data;
-    return (fstat(fildes, &st) >= 0 && S_ISSOCK(st.st_mode));
-}
+#ifdef SIOCINQ
 
 
+/*
+ * We have conflicts:
+ * SIOCINQ -- sockets only
+ * TIOCINQ -- terminals only
+ * FIONREAD -- everything else
+ */
 const explain_iocontrol_t explain_iocontrol_siocinq =
 {
     "SIOCINQ", /* name */
     SIOCINQ, /* value */
-    disambiguate,
+    explain_iocontrol_disambiguate_is_a_socket,
     0, /* print_name */
     0, /* print_data */
     0, /* print_explanation */
+    0, /* print_data_returned */
+    __FILE__,
+    __LINE__,
 };
+
+#else
+
+const explain_iocontrol_t explain_iocontrol_siocinq =
+{
+    0, /* name */
+    0, /* value */
+    0, /* disambiguate */
+    0, /* print_name */
+    0, /* print_data */
+    0, /* print_explanation */
+    0, /* print_data_returned */
+    __FILE__,
+    __LINE__,
+};
+
+#endif
