@@ -18,21 +18,44 @@
  */
 
 #include <libexplain/ac/sys/ioctl.h>
+#include <libexplain/ac/sys/stat.h>
 #include <libexplain/ac/linux/sockios.h>
 
 #include <libexplain/iocontrol/siocoutq.h>
 
+#ifdef SIOCOUTQ
 
-#ifndef SIOCOUTQ
-#define SIOCOUTQ -1
-#endif
-
+/*
+ * We have conflicts...
+ * SIOCOUTQ -- sockets
+ * TIOCOUTQ -- terminals
+ */
 const explain_iocontrol_t explain_iocontrol_siocoutq =
 {
     "SIOCOUTQ", /* name */
     SIOCOUTQ, /* value */
+    explain_iocontrol_disambiguate_is_a_socket,
+    0, /* print_name */
+    0, /* print_data */
+    0, /* print_explanation */
+    0, /* print_data_returned */
+    __FILE__,
+    __LINE__,
+};
+
+#else
+
+const explain_iocontrol_t explain_iocontrol_siocoutq =
+{
+    0, /* name */
+    0, /* value */
     0, /* disambiguate */
     0, /* print_name */
     0, /* print_data */
     0, /* print_explanation */
+    0, /* print_data_returned */
+    __FILE__,
+    __LINE__,
 };
+
+#endif
