@@ -18,13 +18,12 @@
  */
 
 #include <libexplain/ac/linux/sockios.h>
+#include <libexplain/ac/sys/sockio.h>
 
 #include <libexplain/iocontrol/siocsifdivert.h>
 
 
-#ifndef SIOCSIFDIVERT
-#define SIOCSIFDIVERT -1
-#endif
+#ifdef SIOCSIFDIVERT
 
 const explain_iocontrol_t explain_iocontrol_siocsifdivert =
 {
@@ -34,4 +33,24 @@ const explain_iocontrol_t explain_iocontrol_siocsifdivert =
     0, /* print_name */
     0, /* print_data */
     0, /* print_explanation */
+    0, /* print_data_returned */
+    __FILE__,
+    __LINE__,
 };
+
+#else
+
+const explain_iocontrol_t explain_iocontrol_siocsifdivert =
+{
+    0, /* name */
+    0, /* value */
+    0, /* disambiguate */
+    0, /* print_name */
+    0, /* print_data */
+    0, /* print_explanation */
+    0, /* print_data_returned */
+    __FILE__,
+    __LINE__,
+};
+
+#endif
