@@ -18,6 +18,7 @@
  */
 
 #include <libexplain/ac/sys/socket.h>
+#include <libexplain/ac/sys/sockio.h>
 
 #include <libexplain/buffer/int.h>
 #include <libexplain/iocontrol/siocspgrp.h>
@@ -43,4 +44,7 @@ const explain_iocontrol_t explain_iocontrol_siocspgrp =
     0, /* print_name */
     print_data,
     0, /* print_explanation */
+    0, /* print_data_returned */
+    __FILE__,
+    __LINE__,
 };
