@@ -22,7 +22,8 @@
 #include <libexplain/iocontrol/tcgets.h>
 
 
-/* #include <sys/ioctl.h> => <asm/ioctls.h> */
+#ifdef TCGETS
+
 const explain_iocontrol_t explain_iocontrol_tcgets =
 {
     "TCGETS", /* name */
@@ -31,4 +32,24 @@ const explain_iocontrol_t explain_iocontrol_tcgets =
     0, /* print_name */
     0, /* print_data */
     0, /* print_explanation */
+    0, /* print_data_returned */
+    __FILE__,
+    __LINE__,
 };
+
+#else
+
+const explain_iocontrol_t explain_iocontrol_tcgets =
+{
+    0, /* name */
+    0, /* value */
+    0, /* disambiguate */
+    0, /* print_name */
+    0, /* print_data */
+    0, /* print_explanation */
+    0, /* print_data_returned */
+    __FILE__,
+    __LINE__,
+};
+
+#endif
