@@ -18,12 +18,15 @@
  */
 
 #include <libexplain/ac/sys/ioctl.h>
+#include <libexplain/ac/stdint.h>
 
-#include <libexplain/buffer/int.h>
+#include <libexplain/buffer/long.h>
 #include <libexplain/iocontrol/tcsbrk.h>
 #include <libexplain/path_is_efault.h>
 
 
+#ifdef TCSBRK
+
 static void
 print_data(const explain_iocontrol_t *p, explain_string_buffer_t *sb,
     int errnum, int fildes, int request, const void *data)
@@ -32,7 +35,7 @@ print_data(const explain_iocontrol_t *p, explain_string_buffer_t *sb,
     (void)errnum;
     (void)fildes;
     (void)request;
-    explain_buffer_int(sb, (int)data);
+    explain_buffer_long(sb, (intptr_t)data);
 }
 
 
@@ -44,4 +47,24 @@ const explain_iocontrol_t explain_iocontrol_tcsbrk =
     0, /* print_name */
     print_data,
     0, /* print_explanation */
+    0, /* print_data_returned */
+    __FILE__,
+    __LINE__,
 };
+
+#else
+
+const explain_iocontrol_t explain_iocontrol_tcsbrk =
+{
+    0, /* name */
+    0, /* value */
+    0, /* disambiguate */
+    0, /* print_name */
+    0, /* print_data */
+    0, /* print_explanation */
+    0, /* print_data_returned */
+    __FILE__,
+    __LINE__,
+};
+
+#endif
