@@ -18,10 +18,12 @@
  */
 
 #include <libexplain/ac/sys/ioctl.h>
+#include <libexplain/ac/termios.h>
 
-#include <libexplain/buffer/int.h>
+#include <libexplain/buffer/tcflow_action.h>
 #include <libexplain/iocontrol/tcxonc.h>
 
+#ifdef TCXONC
 
 static void
 print_data(const explain_iocontrol_t *p, explain_string_buffer_t *sb,
@@ -31,7 +33,7 @@ print_data(const explain_iocontrol_t *p, explain_string_buffer_t *sb,
     (void)errnum;
     (void)fildes;
     (void)request;
-    explain_buffer_int(sb, (int)data);
+    explain_buffer_tcflow_action(sb, (long)data);
 }
 
 
@@ -43,4 +45,24 @@ const explain_iocontrol_t explain_iocontrol_tcxonc =
     0, /* print_name */
     print_data,
     0, /* print_explanation */
+    0, /* print_data_returned */
+    __FILE__,
+    __LINE__,
 };
+
+#else
+
+const explain_iocontrol_t explain_iocontrol_tcxonc =
+{
+    0, /* name */
+    0, /* value */
+    0, /* disambiguate */
+    0, /* print_name */
+    0, /* print_data */
+    0, /* print_explanation */
+    0, /* print_data_returned */
+    __FILE__,
+    __LINE__,
+};
+
+#endif
