@@ -18,10 +18,27 @@
  */
 
 #include <libexplain/ac/sys/ioctl.h>
+#include <libexplain/ac/sys/stat.h>
 
 #include <libexplain/buffer/int.h>
 #include <libexplain/iocontrol/tiocinq.h>
 
+#ifdef TIOCINQ
+
+
+static int
+disambiguate(int fildes, int request, const void *data)
+{
+    struct stat     st;
+
+    /* success = 0, failure = -1 */
+    (void)request;
+    (void)data;
+    if (fstat(fildes, &st) >= 0 && S_ISCHR(st.st_mode))
+        return 0;
+    return -1;
+}
+
 
 static void
 print_data(const explain_iocontrol_t *p, explain_string_buffer_t *sb,
@@ -35,12 +52,38 @@ print_data(const explain_iocontrol_t *p, explain_string_buffer_t *sb,
 }
 
 
+/*
+ * We have conflicts...
+ * SIOCINQ - sockets only
+ * TIOCINQ - terminals only
+ * FIONREAD - everything else
+ */
 const explain_iocontrol_t explain_iocontrol_tiocinq =
 {
     "TIOCINQ", /* name */
     TIOCINQ, /* value */
-    0, /* disambiguate */
+    disambiguate,
     0, /* print_name */
     print_data,
     0, /* print_explanation */
+    0, /* print_data_returned */
+    __FILE__,
+    __LINE__,
 };
+
+#else
+
+const explain_iocontrol_t explain_iocontrol_tiocinq =
+{
+    0, /* name */
+    0, /* value */
+    0, /* disambiguate */
+    0, /* print_name */
+    0, /* print_data */
+    0, /* print_explanation */
+    0, /* print_data_returned */
+    __FILE__,
+    __LINE__,
+};
+
+#endif
