@@ -23,6 +23,8 @@
 #include <libexplain/iocontrol/tiocmiwait.h>
 
 
+#ifdef TIOCMIWAIT
+
 static void
 print_data(const explain_iocontrol_t *p, explain_string_buffer_t *sb,
     int errnum, int fildes, int request, const void *data)
@@ -31,7 +33,7 @@ print_data(const explain_iocontrol_t *p, explain_string_buffer_t *sb,
     (void)errnum;
     (void)fildes;
     (void)request;
-    explain_buffer_tiocm(sb, (int)data);
+    explain_buffer_tiocm(sb, (long)data);
 }
 
 
@@ -43,4 +45,24 @@ const explain_iocontrol_t explain_iocontrol_tiocmiwait =
     0, /* print_name */
     print_data,
     0, /* print_explanation */
+    0, /* print_data_returned */
+    __FILE__,
+    __LINE__,
 };
+
+#else
+
+const explain_iocontrol_t explain_iocontrol_tiocmiwait =
+{
+    0, /* name */
+    0, /* value */
+    0, /* disambiguate */
+    0, /* print_name */
+    0, /* print_data */
+    0, /* print_explanation */
+    0, /* print_data_returned */
+    __FILE__,
+    __LINE__,
+};
+
+#endif
