@@ -22,6 +22,8 @@
 #include <libexplain/iocontrol/tiocnotty.h>
 
 
+#ifdef TIOCNOTTY
+
 const explain_iocontrol_t explain_iocontrol_tiocnotty =
 {
     "TIOCNOTTY", /* name */
@@ -30,4 +32,24 @@ const explain_iocontrol_t explain_iocontrol_tiocnotty =
     0, /* print_name */
     0, /* print_data */
     0, /* print_explanation */
+    0, /* print_data_returned */
+    __FILE__,
+    __LINE__,
 };
+
+#else
+
+const explain_iocontrol_t explain_iocontrol_tiocnotty =
+{
+    0, /* name */
+    0, /* value */
+    0, /* disambiguate */
+    0, /* print_name */
+    0, /* print_data */
+    0, /* print_explanation */
+    0, /* print_data_returned */
+    __FILE__,
+    __LINE__,
+};
+
+#endif
