@@ -22,12 +22,39 @@
 #include <libexplain/iocontrol/tiocoutq.h>
 
 
+#ifdef TIOCOUTQ
+
+/*
+ * We have conflicts
+ * TIOCOUTQ -- for terminals (coded as "everything else");
+ * SIOCOUTQ -- for sockets
+ */
 const explain_iocontrol_t explain_iocontrol_tiocoutq =
 {
     "TIOCOUTQ", /* name */
     TIOCOUTQ, /* value */
+    explain_iocontrol_disambiguate_is_not_a_socket,
+    0, /* print_name */
+    0, /* print_data */
+    0, /* print_explanation */
+    0, /* print_data_returned */
+    __FILE__,
+    __LINE__,
+};
+
+#else
+
+const explain_iocontrol_t explain_iocontrol_tiocoutq =
+{
+    0, /* name */
+    0, /* value */
     0, /* disambiguate */
     0, /* print_name */
     0, /* print_data */
     0, /* print_explanation */
+    0, /* print_data_returned */
+    __FILE__,
+    __LINE__,
 };
+
+#endif
