@@ -23,6 +23,8 @@
 #include <libexplain/iocontrol/tiocslcktrmios.h>
 
 
+#ifdef TIOCSLCKTRMIOS
+
 static void
 print_data(const explain_iocontrol_t *p, explain_string_buffer_t *sb,
     int errnum, int fildes, int request, const void *data)
@@ -43,4 +45,24 @@ const explain_iocontrol_t explain_iocontrol_tiocslcktrmios =
     0, /* print_name */
     print_data,
     0, /* print_explanation */
+    0, /* print_data_returned */
+    __FILE__,
+    __LINE__,
 };
+
+#else
+
+const explain_iocontrol_t explain_iocontrol_tiocslcktrmios =
+{
+    0, /* name */
+    0, /* value */
+    0, /* disambiguate */
+    0, /* print_name */
+    0, /* print_data */
+    0, /* print_explanation */
+    0, /* print_data_returned */
+    __FILE__,
+    __LINE__,
+};
+
+#endif
