@@ -28,23 +28,8 @@
 void
 explain_lchown_or_die(const char *pathname, int owner, int group)
 {
-#ifdef HAVE_LCHOWN
-    if (lchown(pathname, owner, group) < 0)
+    if (explain_lchown_on_error(pathname, owner, group) < 0)
     {
-        explain_program_name_assemble_internal(1);
-        explain_wrap_and_print
-        (
-            stderr,
-            explain_lchown(pathname, owner, group)
-        );
         exit(EXIT_FAILURE);
     }
-#else
-    explain_wrap_and_print
-    (
-        stderr,
-        explain_errno_lchown(ENOSYS, pathname, owner, group)
-    );
-    exit(EXIT_FAILURE);
-#endif
 }
