@@ -28,10 +28,8 @@
 void
 explain_link_or_die(const char *oldpath, const char *newpath)
 {
-    if (link(oldpath, newpath) < 0)
+    if (explain_link_on_error(oldpath, newpath) < 0)
     {
-        explain_program_name_assemble_internal(1);
-        explain_wrap_and_print(stderr, explain_link(oldpath, newpath));
         exit(EXIT_FAILURE);
     }
 }
