@@ -28,10 +28,8 @@
 void
 explain_listen_or_die(int fildes, int backlog)
 {
-    if (listen(fildes, backlog) < 0)
+    if (explain_listen_on_error(fildes, backlog) < 0)
     {
-        explain_program_name_assemble_internal(1);
-        explain_wrap_and_print(stderr, explain_listen(fildes, backlog));
         exit(EXIT_FAILURE);
     }
 }
