@@ -28,17 +28,11 @@
 long long
 explain_lseek_or_die(int fildes, long long offset, int whence)
 {
-    long long       result;
+    off_t           result;
 
-    result = lseek(fildes, offset, whence);
-    if (result < 0)
+    result = explain_lseek_on_error(fildes, offset, whence);
+    if (result == (off_t)-1)
     {
-        explain_program_name_assemble_internal(1);
-        explain_wrap_and_print
-        (
-            stderr,
-            explain_lseek(fildes, offset, whence)
-        );
         exit(EXIT_FAILURE);
     }
     return result;
