@@ -28,10 +28,8 @@
 void
 explain_lstat_or_die(const char *pathname, struct stat *buf)
 {
-    if (lstat(pathname, buf) < 0)
+    if (explain_lstat_on_error(pathname, buf) < 0)
     {
-        explain_program_name_assemble_internal(1);
-        explain_wrap_and_print(stderr, explain_lstat(pathname, buf));
         exit(EXIT_FAILURE);
     }
 }
