@@ -28,23 +28,15 @@
 void *
 explain_malloc_or_die(size_t size)
 {
-    size_t          ok_size;
     void            *result;
 
-     /*
-      * Common mis-implementation of the posix standard:
-      * Some malloc implementations can't cope with a size of zero.
-      */
-    ok_size = size ? size : 1;
-    errno = ENOMEM;
-    result = malloc(ok_size);
+    result = explain_malloc_on_error(size);
     if (!result)
     {
-        explain_program_name_assemble_internal(1);
-        explain_wrap_and_print(stderr, explain_malloc(size));
         exit(EXIT_FAILURE);
     }
     return result;
 }
 
+
 /* vim:ts=8:sw=4:et */
