@@ -22,7 +22,7 @@
 
 void
 explain_message_errno_fread(char *message, int message_size, int errnum,
-    void *ptr, long size, long nmemb, FILE *fp)
+    void *ptr, size_t size, size_t nmemb, FILE *fp)
 {
     explain_string_buffer_t sb;
 
