@@ -23,7 +23,7 @@
 
 void
 explain_message_errno_read(char *message, int message_size, int errnum,
-    int fildes, const void *data, long data_size)
+    int fildes, const void *data, size_t data_size)
 {
     explain_string_buffer_t sb;
 
