@@ -22,7 +22,7 @@
 
 void
 explain_message_errno_readlink(char *message, int message_size, int errnum,
-    const char *pathname, char *data, int data_size)
+    const char *pathname, char *data, size_t data_size)
 {
     explain_string_buffer_t sb;
 
