@@ -1,12 +1,11 @@
 /*
  * libexplain - Explain errno values returned by libc functions
  * Copyright (C) 2008, 2009 Peter Miller
- * Written by Peter Miller <pmiller@opensource.org.au>
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License as
- * published by the Free Software Foundation; either version 3 of the
- * License, or (at your option) any later version.
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU Lesser General Public License as published by
+ * the Free Software Foundation; either version 3 of the License, or (at
+ * your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -14,11 +13,10 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include <libexplain/ac/errno.h>
-#include <libexplain/ac/stdio.h>
 
 #include <libexplain/fflush.h>
 
@@ -28,3 +26,6 @@ explain_message_fflush(char *message, int message_size, FILE *fp)
 {
     explain_message_errno_fflush(message, message_size, errno, fp);
 }
+
+
+/* vim: set ts=8 sw=4 et */
