@@ -23,7 +23,7 @@
 
 void
 explain_message_fread(char *message, int message_size, void *ptr,
-    long size, long nmemb, FILE *fp)
+    size_t size, size_t nmemb, FILE *fp)
 {
     explain_message_errno_fread
     (
