@@ -24,7 +24,7 @@
 
 void
 explain_message_read(char *message, int message_size, int fildes,
-    const void *data, long data_size)
+    const void *data, size_t data_size)
 {
     explain_message_errno_read
     (
