@@ -23,7 +23,7 @@
 
 void
 explain_message_readlink(char *message, int message_size,
-    const char *pathname, char *data, int data_size)
+    const char *pathname, char *data, size_t data_size)
 {
     explain_message_errno_readlink
     (
