@@ -28,10 +28,8 @@
 void
 explain_mkdir_or_die(const char *pathname, int mode)
 {
-    if (mkdir(pathname, mode) < 0)
+    if (explain_mkdir_on_error(pathname, mode) < 0)
     {
-        explain_program_name_assemble_internal(1);
-        explain_wrap_and_print(stderr, explain_mkdir(pathname, mode));
         exit(EXIT_FAILURE);
     }
 }
