@@ -30,11 +30,9 @@ explain_opendir_or_die(const char *pathname)
 {
     DIR             *result;
 
-    result = opendir(pathname);
+    result = explain_opendir_on_error(pathname);
     if (!result)
     {
-        explain_program_name_assemble_internal(1);
-        explain_wrap_and_print(stderr, explain_opendir(pathname));
         exit(EXIT_FAILURE);
     }
     return result;
