@@ -29,11 +29,9 @@ explain_pclose_or_die(FILE *fp)
 {
     int             result;
 
-    result = pclose(fp);
+    result = explain_pclose_on_error(fp);
     if (result < 0)
     {
-        explain_program_name_assemble_internal(1);
-        explain_wrap_and_print(stderr, explain_pclose(fp));
         exit(EXIT_FAILURE);
     }
     return result;
