@@ -28,10 +28,8 @@
 void
 explain_pipe_or_die(int *pipefd)
 {
-    if (pipe(pipefd) < 0)
+    if (explain_pipe_on_error(pipefd) < 0)
     {
-        explain_program_name_assemble_internal(1);
-        explain_wrap_and_print(stderr, explain_pipe(pipefd));
         exit(EXIT_FAILURE);
     }
 }
