@@ -29,11 +29,9 @@ explain_popen_or_die(const char *command, const char *flags)
 {
     FILE            *fp;
 
-    fp = popen(command, flags);
+    fp = explain_popen_on_error(command, flags);
     if (!fp)
     {
-        explain_program_name_assemble_internal(1);
-        explain_wrap_and_print(stderr, explain_popen(command, flags));
         exit(EXIT_FAILURE);
     }
     return fp;
