@@ -31,8 +31,7 @@ static
 void
 explain_putc_or_die_failed(int c, FILE *fp)
 {
-    explain_program_name_assemble_internal(1);
-    explain_wrap_and_print(stderr, explain_putc(c, fp));
+    explain_putc_on_error_failed(c, fp);
     exit(EXIT_FAILURE);
 }
 
