@@ -32,11 +32,9 @@ explain_readdir_or_die(DIR *dir)
     struct dirent   *result;
 
     errno = 0;
-    result = readdir(dir);
+    result = explain_readdir_on_error(dir);
     if (!result && errno)
     {
-        explain_program_name_assemble_internal(1);
-        explain_wrap_and_print(stderr, explain_readdir(dir));
         exit(EXIT_FAILURE);
     }
     return result;
