@@ -22,7 +22,7 @@
 
 
 const char *
-explain_readlink(const char *pathname, char *data, int data_size)
+explain_readlink(const char *pathname, char *data, size_t data_size)
 {
     return explain_errno_readlink(errno, pathname, data, data_size);
 }
