@@ -27,10 +27,8 @@
 void
 explain_rename_or_die(const char *oldpath, const char *newpath)
 {
-    if (rename(oldpath, newpath) < 0)
+    if (explain_rename_on_error(oldpath, newpath) < 0)
     {
-        explain_program_name_assemble_internal(1);
-        explain_wrap_and_print(stderr, explain_rename(oldpath, newpath));
         exit(EXIT_FAILURE);
     }
 }
