@@ -16,12 +16,9 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <libexplain/ac/stdio.h>
 #include <libexplain/ac/stdlib.h>
 
-#include <libexplain/option.h>
 #include <libexplain/select.h>
-#include <libexplain/wrap_and_print.h>
 
 
 int
@@ -30,15 +27,10 @@ explain_select_or_die(int nfds, fd_set *readfds, fd_set *writefds,
 {
     int             result;
 
-    result = select(nfds, readfds, writefds, exceptfds, timeout);
+    result =
+        explain_select_on_error(nfds, readfds, writefds, exceptfds, timeout);
     if (result < 0)
     {
-        explain_program_name_assemble_internal(1);
-        explain_wrap_and_print
-        (
-            stderr,
-            explain_select(nfds, readfds, writefds, exceptfds, timeout)
-        );
         exit(EXIT_FAILURE);
     }
     return result;
