@@ -16,22 +16,16 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <libexplain/ac/stdio.h>
 #include <libexplain/ac/stdlib.h>
-#include <libexplain/ac/unistd.h>
 
-#include <libexplain/option.h>
 #include <libexplain/symlink.h>
-#include <libexplain/wrap_and_print.h>
 
 
 void
 explain_symlink_or_die(const char *oldpath, const char *newpath)
 {
-    if (symlink(oldpath, newpath) < 0)
+    if (explain_symlink_on_error(oldpath, newpath) < 0)
     {
-        explain_program_name_assemble_internal(1);
-        explain_wrap_and_print(stderr, explain_symlink(oldpath, newpath));
         exit(EXIT_FAILURE);
     }
 }
