@@ -16,12 +16,9 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <libexplain/ac/stdio.h>
 #include <libexplain/ac/stdlib.h>
 
-#include <libexplain/option.h>
 #include <libexplain/system.h>
-#include <libexplain/wrap_and_print.h>
 
 
 int
@@ -29,11 +26,9 @@ explain_system_or_die(const char *command)
 {
     int             result;
 
-    result = system(command);
+    result = explain_system_on_error(command);
     if (result < 0)
     {
-        explain_program_name_assemble_internal(1);
-        explain_wrap_and_print(stderr, explain_system(command));
         exit(EXIT_FAILURE);
     }
     return result;
