@@ -16,22 +16,16 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <libexplain/ac/stdio.h>
 #include <libexplain/ac/stdlib.h>
-#include <libexplain/ac/unistd.h>
 
-#include <libexplain/option.h>
 #include <libexplain/unlink.h>
-#include <libexplain/wrap_and_print.h>
 
 
 void
 explain_unlink_or_die(const char *pathname)
 {
-    if (unlink(pathname) < 0)
+    if (explain_unlink_on_error(pathname) < 0)
     {
-        explain_program_name_assemble_internal(1);
-        explain_wrap_and_print(stderr, explain_unlink(pathname));
         exit(EXIT_FAILURE);
     }
 }
