@@ -16,13 +16,9 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <libexplain/ac/stdio.h>
 #include <libexplain/ac/stdlib.h>
-#include <libexplain/ac/sys/wait.h>
 
-#include <libexplain/option.h>
 #include <libexplain/wait4.h>
-#include <libexplain/wrap_and_print.h>
 
 
 int
@@ -31,15 +27,9 @@ explain_wait4_or_die(int pid, int *status, int options,
 {
     int             result;
 
-    result = wait4(pid, status, options, rusage);
+    result = explain_wait4_on_error(pid, status, options, rusage);
     if (result < 0)
     {
-        explain_program_name_assemble_internal(1);
-        explain_wrap_and_print
-        (
-            stderr,
-            explain_wait4(pid, status, options, rusage)
-        );
         exit(EXIT_FAILURE);
     }
     return result;
