@@ -16,13 +16,9 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <libexplain/ac/stdio.h>
 #include <libexplain/ac/stdlib.h>
-#include <libexplain/ac/sys/wait.h>
 
-#include <libexplain/option.h>
 #include <libexplain/waitpid.h>
-#include <libexplain/wrap_and_print.h>
 
 
 int
@@ -30,15 +26,9 @@ explain_waitpid_or_die(int pid, int *status, int options)
 {
     int             result;
 
-    result = waitpid(pid, status, options);
+    result = explain_waitpid_on_error(pid, status, options);
     if (result < 0)
     {
-        explain_program_name_assemble_internal(1);
-        explain_wrap_and_print
-        (
-            stderr,
-            explain_waitpid(pid, status, options)
-        );
         exit(EXIT_FAILURE);
     }
     return result;
