@@ -23,7 +23,7 @@
 
 
 const char *
-explain_write(int fildes, const void *data, long data_size)
+explain_write(int fildes, const void *data, size_t data_size)
 {
     return explain_errno_write(errno, fildes, data, data_size);
 }
