@@ -22,8 +22,8 @@ TEST_SUBJECT="ioctl EINVAL"
 . test_prelude
 
 cat > test.ok << 'fubar'
-ioctl(fildes = 42, request = _IO(0, 0, 0), data = NULL) failed, Invalid
-argument (EINVAL) because ioctl request or ioctl data is not valid
+ioctl(fildes = 42, request = _IO(0x00, 0), data = NULL) failed, Invalid
+argument (EINVAL) because data is the NULL pointer
 fubar
 test $? -eq 0 || no_result
 
